@@ -1,7 +1,7 @@
 /*
  * applications.h - the Qucs application list
  *
- * Copyright (C) 2005, 2006, 2007, 2008, 2009 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005-2011 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: applications.h,v 1.34 2009/04/19 12:01:33 ela Exp $
+ * $Id: applications.h 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -670,6 +670,10 @@ struct application_t eqn::applications[] = {
     { TAG_VECTOR, TAG_VECTOR } },
   { "Freq2Time", TAG_VECTOR, evaluate::freq2time_v_v, 2,
     { TAG_VECTOR, TAG_VECTOR } },
+  { "receiver",  TAG_VECTOR, evaluate::receiver_v_v,  2,
+    { TAG_VECTOR, TAG_VECTOR } },
+  { "receiver",  TAG_VECTOR, evaluate::receiver_v_v,  3,
+    { TAG_VECTOR, TAG_VECTOR, TAG_DOUBLE } },
   { "fftshift",  TAG_VECTOR, evaluate::fftshift_v, 1, { TAG_VECTOR } },
 
   { "xvalue", TAG_COMPLEX, evaluate::xvalue_d, 2,
@@ -887,10 +891,28 @@ struct application_t eqn::applications[] = {
     { TAG_VECTOR, TAG_DOUBLE,  TAG_VECTOR } },
   { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
     { TAG_VECTOR, TAG_COMPLEX, TAG_VECTOR } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_BOOLEAN, TAG_BOOLEAN } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_DOUBLE,  TAG_BOOLEAN } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_COMPLEX, TAG_BOOLEAN } },
   { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
     { TAG_VECTOR, TAG_VECTOR,  TAG_BOOLEAN } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_BOOLEAN, TAG_DOUBLE } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_DOUBLE,  TAG_DOUBLE } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_COMPLEX, TAG_DOUBLE } },
   { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
     { TAG_VECTOR, TAG_VECTOR,  TAG_DOUBLE } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_BOOLEAN, TAG_COMPLEX } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_DOUBLE,  TAG_COMPLEX } },
+  { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
+    { TAG_VECTOR, TAG_COMPLEX, TAG_COMPLEX } },
   { "?:", TAG_VECTOR,  evaluate::ifthenelse_v_v_v, 3,
     { TAG_VECTOR, TAG_VECTOR,  TAG_COMPLEX } },
 
@@ -961,8 +983,44 @@ struct application_t eqn::applications[] = {
   { ">",  TAG_VECTOR,  evaluate::greater_v_v, 2,
     { TAG_VECTOR,  TAG_VECTOR  } },
 
-  { "==", TAG_BOOLEAN, evaluate::equal_d_d, 2,    { TAG_DOUBLE, TAG_DOUBLE } },
-  { "!=", TAG_BOOLEAN, evaluate::notequal_d_d, 2, { TAG_DOUBLE, TAG_DOUBLE } },
+  { "==", TAG_BOOLEAN, evaluate::equal_d_d, 2,
+    { TAG_DOUBLE, TAG_DOUBLE } },
+  { "==", TAG_BOOLEAN, evaluate::equal_d_c, 2,
+    { TAG_DOUBLE, TAG_COMPLEX } },
+  { "==", TAG_BOOLEAN, evaluate::equal_d_v, 2,
+    { TAG_DOUBLE, TAG_VECTOR } },
+  { "==",  TAG_BOOLEAN, evaluate::equal_c_d, 2,
+    { TAG_COMPLEX, TAG_DOUBLE  } },
+  { "==",  TAG_BOOLEAN, evaluate::equal_c_c, 2,
+    { TAG_COMPLEX, TAG_COMPLEX } },
+  { "==",  TAG_VECTOR,  evaluate::equal_c_v, 2,
+    { TAG_COMPLEX, TAG_VECTOR  } },
+  { "==",  TAG_VECTOR,  evaluate::equal_v_d, 2,
+    { TAG_VECTOR,  TAG_DOUBLE  } },
+  { "==",  TAG_VECTOR,  evaluate::equal_v_c, 2,
+    { TAG_VECTOR,  TAG_COMPLEX } },
+  { "==",  TAG_VECTOR,  evaluate::equal_v_v, 2,
+    { TAG_VECTOR,  TAG_VECTOR  } },
+
+  { "!=", TAG_BOOLEAN, evaluate::notequal_d_d, 2,
+    { TAG_DOUBLE, TAG_DOUBLE } },
+  { "!=", TAG_BOOLEAN, evaluate::notequal_d_c, 2,
+    { TAG_DOUBLE, TAG_COMPLEX } },
+  { "!=", TAG_BOOLEAN, evaluate::notequal_d_v, 2,
+    { TAG_DOUBLE, TAG_VECTOR } },
+  { "!=",  TAG_BOOLEAN, evaluate::notequal_c_d, 2,
+    { TAG_COMPLEX, TAG_DOUBLE  } },
+  { "!=",  TAG_BOOLEAN, evaluate::notequal_c_c, 2,
+    { TAG_COMPLEX, TAG_COMPLEX } },
+  { "!=",  TAG_VECTOR,  evaluate::notequal_c_v, 2,
+    { TAG_COMPLEX, TAG_VECTOR  } },
+  { "!=",  TAG_VECTOR,  evaluate::notequal_v_d, 2,
+    { TAG_VECTOR,  TAG_DOUBLE  } },
+  { "!=",  TAG_VECTOR,  evaluate::notequal_v_c, 2,
+    { TAG_VECTOR,  TAG_COMPLEX } },
+  { "!=",  TAG_VECTOR,  evaluate::notequal_v_v, 2,
+    { TAG_VECTOR,  TAG_VECTOR  } },
+
   { "!",  TAG_BOOLEAN, evaluate::not_b, 1,   { TAG_BOOLEAN } },
   { "||", TAG_BOOLEAN, evaluate::or_b_b, 2,  { TAG_BOOLEAN, TAG_BOOLEAN } },
   { "&&", TAG_BOOLEAN, evaluate::and_b_b, 2, { TAG_BOOLEAN, TAG_BOOLEAN } },
