@@ -1,7 +1,7 @@
 /*
  * amplifier.cpp - amplifier class implementation
  *
- * Copyright (C) 2004, 2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004, 2008, 2010 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2008 Michael Margraf <Michael.Margraf@alumni.TU-Berlin.DE>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: amplifier.cpp,v 1.8 2008/10/07 20:15:32 ela Exp $
+ * $Id: amplifier.cpp 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -73,7 +73,7 @@ void amplifier::calcNoiseSP (nr_double_t) {
   nr_double_t z2 = getPropertyDouble ("Z2");
   nr_double_t NF = getPropertyDouble ("NF");
   setN (NODE_1, NODE_1, 0);
-  setN (NODE_2, NODE_2, 4 * z0 * z2 * sqrt (g) * (NF - 1) / sqr (z2 + z0));
+  setN (NODE_2, NODE_2, 4 * z0 * z2 * sqr (g) * (NF - 1) / sqr (z2 + z0));
   setN (NODE_1, NODE_2, 0);
   setN (NODE_2, NODE_1, 0);
 }
@@ -116,7 +116,7 @@ void amplifier::calcNoiseAC (nr_double_t) {
   nr_double_t z2 = getPropertyDouble ("Z2");
   nr_double_t NF = getPropertyDouble ("NF");
   setN (NODE_1, NODE_1, 0);
-  setN (NODE_2, NODE_2, 4 * sqrt (g) * (NF - 1) / z2);
+  setN (NODE_2, NODE_2, 4 * sqr (g) * (NF - 1) / z2);
   setN (NODE_1, NODE_2, 0);
   setN (NODE_2, NODE_1, 0);
 }
