@@ -1,7 +1,7 @@
 /*
  * component_id.h - global component identifier header file
  *
- * Copyright (C) 2003-2009 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2003-2011 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: component_id.h,v 1.65 2009/04/01 18:54:54 ela Exp $
+ * $Id: component_id.h 1826 2011-03-12 01:00:56Z ela $
  *
  */
 
@@ -72,6 +72,7 @@ enum circuit_type {
   CIR_TSWITCH,
   CIR_RELAIS,
   CIR_TLINE,
+  CIR_CTLINE,
   CIR_COAXLINE,
   CIR_RECTANGULAR,
   CIR_TWISTEDPAIR,
@@ -86,6 +87,7 @@ enum circuit_type {
   CIR_IRECT,
   CIR_AMPLIFIER,
   CIR_COUPLER,
+  CIR_HYBRID,
   CIR_RFEDD,
 
   // noise sources
@@ -126,6 +128,7 @@ enum circuit_type {
   CIR_DIAC,
   CIR_TRIAC,
   CIR_THYRISTOR,
+  CIR_TUNNELDIODE,
 
   // digital components
   CIR_INVERTER,
@@ -149,9 +152,13 @@ enum circuit_type {
   CIR_MESFET,
   CIR_EKV26MOS,
   CIR_hicumL0V1p2,
+  CIR_hicumL0V1p2g,
+  CIR_hicumL0V1p3,
   CIR_hicumL2V2p23,
+  CIR_hicumL2V2p24,
   CIR_photodiode,
   CIR_phototransistor,
+  CIR_nigbt,
 
   // digital verilog devices
   CIR_dff_SR,
