@@ -31,6 +31,8 @@ inline double _asin(double arg)            { return  asin(arg); }
 inline double _d0_asin(double arg)         { return (+1.0/sqrt(1-arg*arg)); }
 inline double _atan(double arg)            { return  atan(arg); }
 inline double _d0_atan(double arg)         { return (+1.0/(1+arg*arg)); }
+inline double _atanh(double arg)           { return  atanh(arg); }
+inline double _d0_atanh(double arg)        { return (+1.0/(1-arg*arg)); }
 inline double _logE(double arg)            { return  log(arg); }
 inline double _d0_logE(double arg)         { return (1.0/arg); }
 inline double _log10(double arg)           { return  log10(arg); }
