@@ -14,7 +14,7 @@
 class log_amp : public circuit
 {
  public:
-  log_amp ();
+  CREATOR (log_amp);
 
   void initDC (void);
   void restartDC (void);
@@ -37,6 +37,11 @@ class log_amp : public circuit
   void initVerilog (void);
   void calcVerilog (void);
   void initModel (void);
+  void loadVariables (void);
+  void initializeModel (void);
+  void initializeInstance (void);
+  void initialStep (void);
+  void finalStep (void);
   matrix calcMatrixY (nr_double_t);
   matrix calcMatrixCy (nr_double_t);
 
@@ -57,6 +62,29 @@ class log_amp : public circuit
   nr_double_t _flicker_exp[5][5];
   nr_double_t _charges[5][5];
   nr_double_t _caps[5][5][5][5];
+
+  // device model parameters
+  nr_double_t Kv;
+  nr_double_t Dk;
+  nr_double_t Ib1;
+  nr_double_t Ibr;
+  nr_double_t M;
+  nr_double_t N;
+  nr_double_t Vosout;
+  nr_double_t Rinp;
+  nr_double_t Fc;
+  nr_double_t Ro;
+  nr_double_t Ntc;
+  nr_double_t Vosouttc;
+  nr_double_t Dktc;
+  nr_double_t Ib1tc;
+  nr_double_t Ibrtc;
+  nr_double_t Tnom;
+
+  // global model variables
+
+
+
 };
 
 #endif /* __log_amp_H__ */
