@@ -14,7 +14,7 @@
 class potentiometer : public circuit
 {
  public:
-  potentiometer ();
+  CREATOR (potentiometer);
 
   void initDC (void);
   void restartDC (void);
@@ -37,6 +37,11 @@ class potentiometer : public circuit
   void initVerilog (void);
   void calcVerilog (void);
   void initModel (void);
+  void loadVariables (void);
+  void initializeModel (void);
+  void initializeInstance (void);
+  void initialStep (void);
+  void finalStep (void);
   matrix calcMatrixY (nr_double_t);
   matrix calcMatrixCy (nr_double_t);
 
@@ -57,6 +62,23 @@ class potentiometer : public circuit
   nr_double_t _flicker_exp[4][4];
   nr_double_t _charges[4][4];
   nr_double_t _caps[4][4][4][4];
+
+  // device model parameters
+  nr_double_t R_pot;
+  nr_double_t Rotation;
+  nr_double_t Taper_Coeff;
+  int LEVEL;
+  nr_double_t Max_Rotation;
+  nr_double_t Conformity;
+  nr_double_t Linearity;
+  nr_double_t Contact_Res;
+  nr_double_t Temp_Coeff;
+  nr_double_t Tnom;
+
+  // global model variables
+
+
+
 };
 
 #endif /* __potentiometer_H__ */
