@@ -1,7 +1,7 @@
 /*
  * check_spice.cpp - checker for a Spice netlist
  *
- * Copyright (C) 2004-2009 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004-2011 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_spice.cpp,v 1.56 2009/04/22 16:33:22 ela Exp $
+ * $Id: check_spice.cpp 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -654,7 +654,9 @@ static void spice_adjust_device (struct definition_t * def,
 	    def->pairs = spice_del_property (def->pairs, p2);
 	    if (level == 0) {
 	      if (version >= 1.11) {
-		if (version >= 1.2)
+		if (version >= 1.3)
+		  def->type = strdup ("hicumL0V1p3");
+		else if (version >= 1.2)
 		  def->type = strdup ("hicumL0V1p2");
 		else
 		  def->type = strdup ("hic0_full");
@@ -673,10 +675,14 @@ static void spice_adjust_device (struct definition_t * def,
 	      def->type = strdup ("hic2_full");
 	      hic = true;
 	    }
-	    else if (level == 2 && version >= 2.23) {
+	    else if (level == 2 && version == 2.23) {
 	      def->type = strdup ("hicumL2V2p23");
 	      hic = true;
 	    }
+	    else if (level == 2 && version >= 2.24) {
+	      def->type = strdup ("hicumL2V2p24");
+	      hic = true;
+	    }
 	  }
 	}
       }
@@ -1499,11 +1505,9 @@ spice_translate_source (struct definition_t * root,
       spice_set_property_value (pulse, ui, v);
       v  = spice_get_property_value (pulse, "TH"); // PW
       v += spice_get_property_value (pulse, "Tr");
-      v += spice_get_property_value (pulse, "Tf");
       spice_set_property_value (pulse, "TH", v);
       v  = spice_get_property_value (pulse, "TL"); // PER
       v -= spice_get_property_value (pulse, "TH");
-      v -= spice_get_property_value (pulse, "Td");
       spice_set_property_value (pulse, "TL", v);
     }
     // single pulse
