@@ -1,7 +1,7 @@
 /*
  * check_vcd.cpp - iterate a vcd file
  *
- * Copyright (C) 2005, 2006, 2008 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2005, 2006, 2008, 2010 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2005 Raimund Jacob <raimi@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: check_vcd.cpp,v 1.15 2008/11/02 19:09:07 ela Exp $
+ * $Id: check_vcd.cpp 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -71,6 +71,51 @@ vcd_find_code (struct vcd_scope * root, char * code) {
   return NULL;
 }
 
+// Free's the given VCD change.
+static void vcd_free_change (struct vcd_change * vc) {
+  free (vc->code);
+  free (vc->value);
+  free (vc);
+}
+
+// Free's the given VCD changeset.
+static void vcd_free_changeset (struct vcd_changeset * cs) {
+  struct vcd_change * vc, * vnext;
+  for (vc = cs->changes; vc; vc = vnext) {
+    vnext = vc->next;
+    vcd_free_change (vc);
+  }
+  free (cs);
+}
+
+#if VCD_FAST
+
+/* Returns changes sets in the list's order itself. */
+static struct vcd_changeset *
+vcd_find_firstset_fast (struct vcd_changeset * root) {
+  static struct vcd_changeset * last = root;
+  struct vcd_changeset * result = NULL;
+  result = last;
+  if (last) last = last->next;
+  return result;
+}
+
+/* Reverses the given change set and returns the pointer to the new
+   root change set. */
+static struct vcd_changeset *
+vcd_reverse_changesets (struct vcd_changeset * root) {
+  struct vcd_changeset * cs = NULL;
+  while (root != NULL) {
+    struct vcd_changeset * next = root->next;
+    root->next = cs;
+    cs = root;
+    root = next;
+  }
+  return cs;
+}
+
+#else
+
 /* Returns the change set with the smallest time stamp which is yet
    unprocessed.  It is based upon the fact that the list is in reverse
    order. */
@@ -87,6 +132,8 @@ vcd_find_firstset (struct vcd_changeset * root) {
   return result;
 }
 
+#endif
+
 /* Looks for the a variable name in the given list of variables. */
 static struct vcd_variable *
 vcd_find_variable (struct vcd_variable * root, struct vcd_vardef * var) {
@@ -106,8 +153,17 @@ static void vcd_sort_changesets (struct vcd_changeset * root) {
   struct vcd_change * vc;
   struct vcd_variable * vv;
 
+#if VCD_FAST
+  // for fast lookup, need to reverse list
+  root = vcd_reverse_changesets (root);
+#endif
+
   // as long as there are still changesets unprocessed
+#if VCD_FAST
+  while ((cs = vcd_find_firstset_fast (root)) != NULL) {
+#else
   while ((cs = vcd_find_firstset (root)) != NULL) {
+#endif
     // create set if necessary
     if (current == NULL || current->t != cs->t) {
       vs = (struct vcd_set *) calloc (1, sizeof (struct vcd_set));
@@ -144,8 +200,12 @@ static void vcd_sort_changesets (struct vcd_changeset * root) {
 	current->variables = vv;
       }
     }
+#ifndef VCD_FAST
     // changeset processed
     cs->done = 1;
+#else
+    //vcd_free_changeset (cs);
+#endif
   }
 }
 
@@ -494,14 +554,7 @@ static void vcd_free_file (struct vcd_file * vcd) {
   struct vcd_changeset * cs, * cnext;
   for (cs = vcd->changesets; cs; cs = cnext) {
     cnext = cs->next;
-    struct vcd_change * vc, * vnext;
-    for (vc = cs->changes; vc; vc = vnext) {
-      vnext = vc->next;
-      free (vc->code);
-      free (vc->value);
-      free (vc);
-    }
-    free (cs);
+    vcd_free_changeset (cs);
   }
   free (vcd);
 }
