@@ -1,7 +1,7 @@
 /*
  * qucs_producer.cpp - the Qucs netlist producer
  *
- * Copyright (C) 2004-2009 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004-2011 Stefan Jahn <stefan@lkcc.org>
  *
  * This is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: qucs_producer.cpp,v 1.32 2009/04/09 18:56:43 ela Exp $
+ * $Id: qucs_producer.cpp 1826 2011-03-12 01:00:56Z ela $
  *
  */
 
@@ -328,6 +328,42 @@ qucs_devices[] = {
     "1 0 0 8 -26 0 0",
     NULL
   },
+  /* hicum/l0 v1.2g bipolar transistor */
+  { "hicumL0V1p2g", "hicumL0V1p2g", "Q", 5,
+    { "Type", "is", "mcf", "mcr", "vef", "ver", "iqf", "fiqf", "iqr", "iqfh",
+      "iqfe", "ahq", "ibes", "mbe", "ires", "mre", "ibcs", "mbc", "cje0",
+      "vde", "ze", "aje", "vdedc", "zedc", "ajedc", "t0", "dt0h", "tbvl",
+      "tef0", "gte", "thcs", "ahc", "tr", "rci0", "vlim", "vpt", "vces",
+      "cjci0", "vdci", "zci", "vptci", "cjcx0", "vdcx", "zcx", "vptcx", "fbc",
+      "rbi0", "vr0e", "vr0c", "fgeo", "rbx", "rcx", "re", "itss", "msf",
+      "iscs", "msc", "cjs0", "vds", "zs", "vpts", "cbcpar", "cbepar", "eavl",
+      "kavl", "kf", "af", "vgb", "vge", "vgc", "vgs", "f1vg", "f2vg", "alt0",
+      "kt0", "zetact", "zetabet", "zetaci", "alvs", "alces", "zetarbi",
+      "zetarbx", "zetarcx", "zetare", "zetaiqf", "alkav", "aleav", "flsh",
+      "rth", "zetarth", "cth", "tnom", "dt", "delte", "deltc", "zetaver",
+      "zetavef", "ibhrec", "Temp", NULL },
+    NULL,
+    "1 0 0 8 -26 0 0",
+    NULL
+  },
+  /* hicum/l0 v1.3 bipolar transistor */
+  { "hicumL0V1p3", "hicumL0V1p3", "Q", 5,
+    { "Type", "is", "it_mod", "mcf", "mcr", "vef", "ver", "aver", "iqf",
+      "fiqf", "iqr", "iqfh", "tfh", "ahq", "ibes", "mbe", "ires", "mre",
+      "ibcs", "mbc", "cje0", "vde", "ze", "aje", "vdedc", "zedc", "ajedc",
+      "t0", "dt0h", "tbvl", "tef0", "gte", "thcs", "ahc", "tr", "rci0",
+      "vlim", "vpt", "vces", "cjci0", "vdci", "zci", "vptci", "cjcx0", "vdcx",
+      "zcx", "vptcx", "fbc", "rbi0", "vr0e", "vr0c", "fgeo", "rbx", "rcx",
+      "re", "itss", "msf", "iscs", "msc", "cjs0", "vds", "zs", "vpts",
+      "cbcpar", "cbepar", "eavl", "kavl", "kf", "af", "vgb", "vge", "vgc",
+      "vgs", "f1vg", "f2vg", "alt0", "kt0", "zetact", "zetabet", "zetaci",
+      "alvs", "alces", "zetarbi", "zetarbx", "zetarcx", "zetare", "zetaiqf",
+      "alkav", "aleav", "zetarth", "tef_temp", "zetaver", "zetavgbe", "dvgbe",
+      "aliqfh", "kiqfh", "flsh", "rth", "cth", "tnom", "dt", "Temp", NULL },
+    NULL,
+    "1 0 0 8 -26 0 0",
+    NULL
+  },
   /* hicum/l2 v2.22 bipolar transistor */
   { "hic2_full", "hic2_full", "Q", 5,
     { "c10", "qp0", "ich", "hfe", "hfc", "hjei", "hjci", "ibeis", "mbei",
@@ -386,6 +422,26 @@ qucs_devices[] = {
     "1 0 0 8 -26 0 0",
     NULL
   },
+  /* hicum/l2 v2.24 bipolar transistor */
+  { "hicumL2V2p24", "hicumL2V2p24", "Q", 5,
+    { "c10", "qp0", "ich", "hfe", "hfc", "hjei", "hjci", "ibeis", "mbei",
+      "ireis", "mrei", "ibeps", "mbep", "ireps", "mrep", "mcf", "tbhrec",
+      "ibcis", "mbci", "ibcxs", "mbcx", "ibets", "abet", "tunode", "favl",
+      "qavl", "alfav", "alqav", "rbi0", "rbx", "fgeo", "fdqr0", "fcrbi",
+      "fqi", "re", "rcx", "itss", "msf", "iscs", "msc", "tsf", "rsu", "csu",
+      "cjei0", "vdei", "zei", "ajei", "cjep0", "vdep", "zep", "ajep",
+      "cjci0", "vdci", "zci", "vptci", "cjcx0", "vdcx", "zcx", "vptcx",
+      "fbcpar", "fbepar", "cjs0", "vds", "zs", "vpts", "t0", "dt0h", "tbvl",
+      "tef0", "gtfe", "thcs", "ahc", "fthc", "rci0", "vlim", "vces", "vpt",
+      "tr", "cbepar", "cbcpar", "alqf", "alit", "flnqs", "kf", "af", "cfbe",
+      "latb", "latl", "vgb", "alt0", "kt0", "zetaci", "alvs", "alces",
+      "zetarbi", "zetarbx", "zetarcx", "zetare", "zetacx", "vge", "vgc",
+      "vgs", "f1vg", "f2vg", "zetact", "zetabet", "alb", "flsh", "rth", "cth",
+      "flcomp", "tnom", "dt", "Temp", NULL },
+    NULL,
+    "1 0 0 8 -26 0 0",
+    NULL
+  },
   /* junction FET */
   { "JFET", "JFET", "J", 3,
     { "Type", "Vt0", "Beta", "Lambda", "Rd", "Rs", "Is", "N", "Isr", "Nr",
