@@ -1,7 +1,7 @@
 /*
  * evaluate.h - definitions for Qucs equation evaluations
  *
- * Copyright (C) 2004, 2005, 2006, 2007, 2009 Stefan Jahn <stefan@lkcc.org>
+ * Copyright (C) 2004-2011 Stefan Jahn <stefan@lkcc.org>
  * Copyright (C) 2006 Gunther Kraut <gn.kraut@t-online.de>
  *
  * This is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: evaluate.h,v 1.50 2009/04/19 12:01:33 ela Exp $
+ * $Id: evaluate.h 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -578,6 +578,7 @@ public:
   static constant * idft_v (constant *);
   static constant * time2freq_v_v (constant *);
   static constant * freq2time_v_v (constant *);
+  static constant * receiver_v_v (constant *);
   static constant * fftshift_v (constant *);
 
   static constant * xvalue_d (constant *);
@@ -749,8 +750,24 @@ public:
   static constant * greaterorequal_v_c (constant *);
   static constant * greaterorequal_v_v (constant *);
   static constant * equal_d_d (constant *);
+  static constant * equal_d_c (constant *);
+  static constant * equal_d_v (constant *);
+  static constant * equal_c_d (constant *);
+  static constant * equal_c_c (constant *);
+  static constant * equal_c_v (constant *);
+  static constant * equal_v_d (constant *);
+  static constant * equal_v_c (constant *);
+  static constant * equal_v_v (constant *);
   static constant * equal_b_b (constant *);
   static constant * notequal_d_d (constant *);
+  static constant * notequal_d_c (constant *);
+  static constant * notequal_d_v (constant *);
+  static constant * notequal_c_d (constant *);
+  static constant * notequal_c_c (constant *);
+  static constant * notequal_c_v (constant *);
+  static constant * notequal_v_d (constant *);
+  static constant * notequal_v_c (constant *);
+  static constant * notequal_v_v (constant *);
   static constant * notequal_b_b (constant *);
   static constant * not_b (constant *);
   static constant * or_b_b (constant *);
