@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
  * Boston, MA 02110-1301, USA.  
  *
- * $Id: valuelist.h,v 1.3 2006/08/18 08:20:17 raimi Exp $
+ * $Id: valuelist.h 1825 2011-03-11 20:42:14Z ela $
  *
  */
 
@@ -54,13 +54,13 @@ class valuelist
   valuelist ();
   ~valuelist ();
   valuelist (const valuelist &);
-  void add (char *, type_t *);
+  void add (const char *, type_t *);
   void append (char *, type_t *);
   void append (valuelist *);
   void del (char *);
   int  length (void);
   int  contains (char *);
-  type_t * get (char *);
+  type_t * get (const char *);
   void clear (void);
 
  private:
