@@ -56,6 +56,7 @@
 #include "vcvs.h"
 #include "ccvs.h"
 #include "tline.h"
+#include "ctline.h"
 #include "tline_4port.h"
 #include "twistedpair.h"
 #include "coaxialline.h"
@@ -86,6 +87,7 @@
 #include "mosfet.h"
 #include "mosfet_sub.h"
 #include "eqndefined.h"
+#include "tunneldiode.h"
 #include "dc_sim.h"
 #include "ac_sim.h"
 #include "tr_sim.h"
@@ -109,6 +111,7 @@
 #include "mutual.h"
 #include "mutual2.h"
 #include "coupler.h"
+#include "hybrid.h"
 #include "switch.h"
 #include "relais.h"
 #include "am_modulator.h"
@@ -144,9 +147,13 @@
 #include "MESFET.h"
 #include "EKV26MOS.h"
 #include "hicumL0V1p2.h"
+#include "hicumL0V1p2g.h"
+#include "hicumL0V1p3.h"
 #include "hicumL2V2p23.h"
+#include "hicumL2V2p24.h"
 #include "photodiode.h"
 #include "phototransistor.h"
+#include "nigbt.h"
 
 #include "dff_SR.h"
 #include "tff_SR.h"
