@@ -106,7 +106,7 @@ QString JK_FlipFlop::verilogCode(int NumPorts)
   if(NumPorts <= 0) { // no truth table simulation ?
     QString td = Props.at(0)->Value;        // delay time
     if(!Verilog_Delay(td, Name)) return td; // time has not VHDL format
-    t = "   " + t + ";\n";
+    if(!td.isEmpty()) t = "   " + td + ";\n";
   }
 
   QString l = "";
