@@ -43,7 +43,7 @@ Component* MOSFET::newOne()
 Element* MOSFET::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("n-MOSFET");
-  BitmapFile = "nmosfet";
+  BitmapFile = (char *) "nmosfet";
 
   if(getNewOne)  return new MOSFET();
   return 0;
@@ -53,7 +53,7 @@ Element* MOSFET::info(QString& Name, char* &BitmapFile, bool getNewOne)
 Element* MOSFET::info_p(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("p-MOSFET");
-  BitmapFile = "pmosfet";
+  BitmapFile = (char *) "pmosfet";
 
   if(getNewOne) {
     MOSFET* p = new MOSFET();
@@ -69,7 +69,7 @@ Element* MOSFET::info_p(QString& Name, char* &BitmapFile, bool getNewOne)
 Element* MOSFET::info_depl(QString& Name, char* &BitmapFile, bool getNewOne)
 {
   Name = QObject::tr("depletion MOSFET");
-  BitmapFile = "dmosfet";
+  BitmapFile = (char *) "dmosfet";
 
   if(getNewOne) {
     MOSFET* p = new MOSFET();
