@@ -1,6 +1,6 @@
 /***************************************************************************
-                          sp_sim.h  -  description
-                             -------------------
+                                sp_sim.h
+                               ----------
     begin                : Sat Aug 23 2003
     copyright            : (C) 2003 by Michael Margraf
     email                : michael.margraf@alumni.tu-berlin.de
@@ -27,7 +27,7 @@ public:
   ~SP_Sim();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
-  void recreate();
+  void recreate(Schematic*);
 };
 
 #endif
