@@ -96,7 +96,7 @@ QString VHDL_File::vhdlCode(int)
 // entity in this file.
 QString VHDL_File::loadFile()
 {
-  QString s, File(Props.getFirst()->Value);
+  QString File(Props.getFirst()->Value);
   QFileInfo Info(File);
   if(Info.isRelative())
     File = QucsWorkDir.filePath(File);
@@ -109,12 +109,169 @@ QString VHDL_File::loadFile()
   File = stream.read();   // QString is better for "find" function
   f.close();
 
+  // parse ports, i.e. network connections; and generics, i.e. parameters
+  VHDL_File_Info VInfo(File);
+  GenNames = VInfo.GenNames;
+  EntityName = VInfo.EntityName;
+  TypeNames = VInfo.TypeNames;
+  GenTypes = VInfo.GenTypes;
+  GenDefs = VInfo.GenDefs;
+  return VInfo.PortNames;
+}
+
+// -------------------------------------------------------
+void VHDL_File::createSymbol()
+{
+  QFontMetrics  metrics(QucsSettings.font);   // get size of text
+  int fHeight = metrics.lineSpacing();
+
+  int No = 0;
+  TypeNames = "";
+  QString tmp, PortNames = loadFile();
+  if(!PortNames.isEmpty())
+    No = PortNames.contains(',') + 1;
+
+  #define HALFWIDTH  17
+  int h = 30*((No-1)/2) + 15;
+  Lines.append(new Line(-HALFWIDTH, -h, HALFWIDTH, -h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line( HALFWIDTH, -h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-HALFWIDTH,  h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-HALFWIDTH, -h,-HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
+
+  tmp = QObject::tr("vhdl");
+  int w = metrics.width(tmp);
+  Texts.append(new Text(w/-2, fHeight/-2, tmp));
+
+  int y = 15-h, i = 0;
+  Port *pp;
+  while(i<No) {
+    Lines.append(new Line(-30,  y,-HALFWIDTH,  y,QPen(QPen::darkBlue,2)));
+    pp = new Port(-30,  y);
+    Ports.append(pp);
+    pp->Type = TypeNames.section(',', i, i);
+    tmp = PortNames.section(',', i, i);
+    w = metrics.width(tmp);
+    Texts.append(new Text(-19-w, y-fHeight-2, tmp));
+    i++;
+
+    if(i == No) break;
+    Lines.append(new Line(HALFWIDTH,  y, 30,  y,QPen(QPen::darkBlue,2)));
+    pp = new Port( 30,  y);
+    Ports.append(pp);
+    pp->Type = TypeNames.section(',', i, i);
+    tmp = PortNames.section(',', i, i);
+    Texts.append(new Text( 20, y-fHeight-2, tmp));
+    y += 60;
+    i++;
+  }
+
+  x1 = -30; y1 = -h-2;
+  x2 =  30; y2 =  h+2;
+  tx = x1+4;
+  ty = y2+4;
+
+  // now create/modify properties
+  No = 0;
+  if(!GenNames.isEmpty())
+    No = GenNames.contains(',') + 1;
+  Property * pr = Props.at(1);
+  for(i=0; i<No; i++) {
+    if (!pr) {
+      pr = new Property(GenNames.section(',', i, i),
+			GenDefs.section(',', i, i), true,
+			QObject::tr("generic variable")+
+			" "+QString::number(i+1));
+      Props.append(pr);
+      pr = 0;
+    }
+    else {
+      pr->Description =
+	QObject::tr("generic variable")+" "+QString::number(i+1);
+      pr->Name = GenNames.section(',', i, i);
+      pr = Props.next();
+    }
+  }
+  // remove remaining properties if necessary
+  y=Props.count()-1;
+  for(i=No; i<y; i++) {
+    Props.removeLast();
+  }
+}
+
+// -------------------------------------------------------
+QString VHDL_File::getSubcircuitFile()
+{
+  // construct full filename
+  QString FileName = Props.getFirst()->Value;
+  return properAbsFileName(FileName);
+}
+
+// -------------------------------------------------------
+bool VHDL_File::createSubNetlist(QTextStream *stream)
+{
+  ErrText = "";
+
+  // check filename
+  QString FileName = Props.getFirst()->Value;
+  if(FileName.isEmpty()) {
+    ErrText += QObject::tr("ERROR: No file name in %1 component \"%2\".").
+      arg(Model).arg(Name);
+    return false;
+  }
+
+  // construct full filename
+  FileName = getSubcircuitFile();
+
+  // open file for reading
+  QFile f(FileName);
+  if(!f.open(IO_ReadOnly)) {
+    ErrText += QObject::tr("ERROR: Cannot open %1 file \"%2\".").
+      arg(Model).arg(FileName);
+    return false;
+  }
+
+  // write the whole VHDL file into the netlist output
+  QByteArray FileContent = f.readAll();
+  f.close();
+  (*stream) << '\n';
+  stream->writeRawBytes(FileContent.data(), FileContent.size());
+  (*stream) << '\n';
+  return true;
+}
+
+// -------------------------------------------------------
+VHDL_File_Info::VHDL_File_Info()
+{
+  EntityName = "";
+  PortNames = "";
+  TypeNames = "";
+  GenTypes = "";
+  GenNames = "";
+  GenDefs = "";
+}
+
+// -------------------------------------------------------
+VHDL_File_Info::VHDL_File_Info(QString File, bool isfile)
+{
+  if (isfile) {
+    QFile f(File);
+    if(!f.open(IO_ReadOnly))
+      File = "";
+    else {
+      QByteArray FileContent = f.readAll();
+      File = QString(FileContent);
+    }
+    f.close();
+  }
+  
+  QString s;
+  PortNames = "";
   int i=0, j, k=0;
   while((i=File.find("--", i)) >= 0) { // remove all VHDL comments
-    j = File.find('\n', i+2);          // (This also finds "--" within a ...
-    if(j < 0)                          //  string, but as no strings are ...
-      File = File.left(i);             //  allowed in entity headers, it ...
-    else                               //  does not matter.)
+    j = File.find('\n', i+2);          // This also finds "--" within a ...
+    if(j < 0)                          // string, but as no strings are ...
+      File = File.left(i);             // allowed in entity headers, it ...
+    else                               // does not matter.
       File.remove(i, j-i);
   }
 
@@ -125,44 +282,43 @@ QString VHDL_File::loadFile()
     Expr.setPattern("\\bentity\\b");  // start of last entity
     k = File.findRev(Expr, k);
     if(k < 0)
-      return QString("");
+      return;
 
     Expr.setPattern("\\bend\\b");    // end of last entity
     i = File.find(Expr, k+7);
     if(i < 0)
-      return QString("");
+      return;
     s = File.mid(k+7, i-k-7);  // cut out entity declaration
 
     Expr.setPattern("\\b");
     i = s.find(Expr);
     if(i < 0)
-      return QString("");
+      return;
     j = s.find(Expr, i+1);
     if(j < 0)
-      return QString("");
+      return;
     EntityName = s.mid(i, j-i);  // save entity name
 
     i = s.find(Expr, j+1);
     if(i < 0)
-      return QString("");
+      return;
     j = s.find(Expr, i+1);
     if(j < 0)
-      return QString("");
+      return;
     if(s.mid(i, j-i).lower() == "is")   // really found start of entity ?
       break;
 
     if(k < 1)    // already searched the whole text
-      return QString("");
+      return;
   }
 
   // parse ports, i.e. network connections; and generics, i.e. parameters
-  GenNames=parseGenerics(s,j);
-  s = parsePorts(s,j);
-  return s;
+  GenNames = parseGenerics(s,j);
+  PortNames = parsePorts(s,j);
 }
 
 // -------------------------------------------------------
-QString VHDL_File::parsePorts(QString s, int j)
+QString VHDL_File_Info::parsePorts(QString s, int j)
 {
   QRegExp Expr;
   Expr.setCaseSensitive(false);
@@ -225,7 +381,7 @@ QString VHDL_File::parsePorts(QString s, int j)
 }
 
 // -------------------------------------------------------
-QString VHDL_File::parseGenerics(QString s, int j)
+QString VHDL_File_Info::parseGenerics(QString s, int j)
 {
   QRegExp Expr;
   Expr.setCaseSensitive(false);
@@ -306,122 +462,3 @@ QString VHDL_File::parseGenerics(QString s, int j)
   GenDefs=defs=defs.left(defs.length()-1);
   return s;
 }
-
-// -------------------------------------------------------
-void VHDL_File::createSymbol()
-{
-  QFontMetrics  metrics(QucsSettings.font);   // get size of text
-  int fHeight = metrics.lineSpacing();
-
-  int No = 0;
-  TypeNames = "";
-  QString tmp, PortNames = loadFile();
-  if(!PortNames.isEmpty())
-    No = PortNames.contains(',') + 1;
-
-  #define HALFWIDTH  17
-  int h = 30*((No-1)/2) + 15;
-  Lines.append(new Line(-HALFWIDTH, -h, HALFWIDTH, -h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( HALFWIDTH, -h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-HALFWIDTH,  h, HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-HALFWIDTH, -h,-HALFWIDTH,  h,QPen(QPen::darkBlue,2)));
-
-  tmp = QObject::tr("vhdl");
-  int w = metrics.width(tmp);
-  Texts.append(new Text(w/-2, fHeight/-2, tmp));
-
-  int y = 15-h, i = 0;
-  Port *pp;
-  while(i<No) {
-    Lines.append(new Line(-30,  y,-HALFWIDTH,  y,QPen(QPen::darkBlue,2)));
-    pp = new Port(-30,  y);
-    Ports.append(pp);
-    pp->Type = TypeNames.section(',', i, i);
-    tmp = PortNames.section(',', i, i);
-    w = metrics.width(tmp);
-    Texts.append(new Text(-19-w, y-fHeight-2, tmp));
-    i++;
-
-    if(i == No) break;
-    Lines.append(new Line(HALFWIDTH,  y, 30,  y,QPen(QPen::darkBlue,2)));
-    pp = new Port( 30,  y);
-    Ports.append(pp);
-    pp->Type = TypeNames.section(',', i, i);
-    tmp = PortNames.section(',', i, i);
-    Texts.append(new Text( 20, y-fHeight-2, tmp));
-    y += 60;
-    i++;
-  }
-
-  x1 = -30; y1 = -h-2;
-  x2 =  30; y2 =  h+2;
-  tx = x1+4;
-  ty = y2+4;
-
-  // now create/modify properties
-  if(!GenNames.isEmpty())
-    No = GenNames.contains(',') + 1;
-  Property * pr = Props.at(1);
-  for(i=0; i<No; i++) {
-    if (!pr) {
-      pr = new Property(GenNames.section(',', i, i),
-			GenDefs.section(',', i, i), true,
-			QObject::tr("generic variable")+
-			" "+QString::number(i+1));
-      Props.append(pr);
-      pr = 0;
-    }
-    else {
-      pr->Description =
-	QObject::tr("generic variable")+" "+QString::number(i+1);
-      pr->Name = GenNames.section(',', i, i);
-      pr = Props.next();
-    }
-  }
-  // remove remaining properties if necessary
-  y=Props.count()-1;
-  for(i=No; i<y; i++) {
-    Props.removeLast();
-  }
-}
-
-// -------------------------------------------------------
-QString VHDL_File::getSubcircuitFile()
-{
-  // construct full filename
-  QString FileName = Props.getFirst()->Value;
-  return properAbsFileName(FileName);
-}
-
-// -------------------------------------------------------
-bool VHDL_File::createSubNetlist(QTextStream *stream)
-{
-  ErrText = "";
-
-  // check filename
-  QString FileName = Props.getFirst()->Value;
-  if(FileName.isEmpty()) {
-    ErrText += QObject::tr("ERROR: No file name in %1 component \"%2\".").
-      arg(Model).arg(Name);
-    return false;
-  }
-
-  // construct full filename
-  FileName = getSubcircuitFile();
-
-  // open file for reading
-  QFile f(FileName);
-  if(!f.open(IO_ReadOnly)) {
-    ErrText += QObject::tr("ERROR: Cannot open %1 file \"%2\".").
-      arg(Model).arg(FileName);
-    return false;
-  }
-
-  // write the whole VHDL file into the netlist output
-  QByteArray FileContent = f.readAll();
-  f.close();
-  (*stream) << '\n';
-  stream->writeRawBytes(FileContent.data(), FileContent.size());
-  (*stream) << '\n';
-  return true;
-}
