@@ -36,8 +36,6 @@ protected:
   QString vhdlCode(int);
   void createSymbol();
   QString loadFile();
-  QString parsePorts(QString, int);
-  QString parseGenerics(QString, int);
 
   QString EntityName;
   QString ErrText;
@@ -47,4 +45,21 @@ protected:
   QString GenDefs;
 };
 
+class VHDL_File_Info {
+public:
+  VHDL_File_Info();
+  VHDL_File_Info(QString, bool isfile = false);
+ ~VHDL_File_Info() {};
+  QString parsePorts(QString, int);
+  QString parseGenerics(QString, int);
+
+public:
+  QString EntityName;
+  QString PortNames;
+  QString TypeNames;
+  QString GenTypes;
+  QString GenNames;
+  QString GenDefs;
+};
+
 #endif
