@@ -258,6 +258,8 @@ DiagramDialog::DiagramDialog(Diagram *d, const QString& _DataSet,
   GraphList = new QListBox(GraphGroup);
   connect(GraphList, SIGNAL(clicked(QListBoxItem*)),
 		     SLOT(slotSelectGraph(QListBoxItem*)));
+  connect(GraphList, SIGNAL(doubleClicked(QListBoxItem*)),
+		     SLOT(slotDeleteGraph()));
   QPushButton *NewButt = new QPushButton(tr("New Graph"), GraphGroup);
   connect(NewButt, SIGNAL(clicked()), SLOT(slotNewGraph()));
   QPushButton *DelButt = new QPushButton(tr("Delete Graph"), GraphGroup);
@@ -658,7 +660,7 @@ void DiagramDialog::slotTakeVar(QListViewItem *Item)
   QString s  = GraphInput->text();
   QString s1 = Item->text(0);
   QFileInfo Info(defaultDataSet);
-  if(ChooseData->currentText() != Info.baseName())
+  if(ChooseData->currentText() != Info.baseName(true))
     s1 = ChooseData->currentText() + ":" + s1;
   GraphInput->setText(s.left(i) + s1 + s.right(s.length()-i));
 
