@@ -35,6 +35,7 @@
 #include "textdoc.h"
 #include "schematic.h"
 #include "components/opt_sim.h"
+#include "components/vhdlfile.h"
 
 
 SimMessage::SimMessage(QWidget *w, QWidget *parent)
@@ -50,11 +51,13 @@ SimMessage::SimMessage(QWidget *w, QWidget *parent)
 
   DocName = Doc->DocName;
   DataDisplay = Doc->DataDisplay;
+  Script = Doc->Script;
   QFileInfo Info(DocName);
   DataSet = QDir::convertSeparators(Info.dirPath()) +
     QDir::separator() + Doc->DataSet;
   showBias = Doc->showBias;     // save some settings as the document...
   SimOpenDpl = Doc->SimOpenDpl; // ...could be closed during the simulation.
+  SimRunScript = Doc->SimRunScript;
 
   all = new QVBoxLayout(this);
   all->setSpacing(5);
@@ -268,13 +271,17 @@ void SimMessage::slotFinishSpiceNetlist()
 // ------------------------------------------------------------------------
 #ifdef __MINGW32__
 #include <windows.h>
-static QString getShortPathName(QString longpath) {
+static QString pathName(QString longpath) {
   const char * lpath = QDir::convertSeparators(longpath).ascii();
   char spath[2048];
   int len = GetShortPathNameA(lpath,spath,sizeof(spath)-1);
   spath[len] = '\0';
   return QString(spath);
 }
+#else
+static QString pathName(QString longpath) {
+  return longpath;
+}
 #endif
 
 // ------------------------------------------------------------------------
@@ -288,38 +295,87 @@ void SimMessage::startSimulator()
   QStringList CommandLine;
   QString SimPath = QDir::convertSeparators (QucsHomeDir.absPath());
 #ifdef __MINGW32__
+  QString QucsDigiLib = "qucsdigilib.bat";
   QString QucsDigi = "qucsdigi.bat";
   QString QucsVeri = "qucsveri.bat";
 #else
+  QString QucsDigiLib = "qucsdigilib";
   QString QucsDigi = "qucsdigi";
   QString QucsVeri = "qucsveri";
 #endif
   SimOpt = NULL;
   bool isVerilog = false;
 
+  // Simulate text window.
   if(DocWidget->inherits("QTextEdit")) {
+
+    TextDoc * Doc = (TextDoc*)DocWidget;
+
     // Take VHDL file in memory as it could contain unsaved changes.
-    Stream << ((TextDoc*)DocWidget)->text();
+    Stream << Doc->text();
     NetlistFile.close();
     ProgText->insert(tr("done.")+"\n");  // of "creating netlist... 
 
-    SimTime = ((TextDoc*)DocWidget)->SimTime;
-#ifdef __MINGW32__
-    CommandLine << getShortPathName(QucsSettings.BinDir + QucsDigi)
-		<< "netlist.txt" << DataSet
-		<< SimTime << getShortPathName(SimPath)
-		<< getShortPathName(QucsSettings.BinDir);
-#else
-    CommandLine << QucsSettings.BinDir + QucsDigi << "netlist.txt" << DataSet
-       << SimTime << SimPath << QucsSettings.BinDir;
-#endif
+    // Simulation.
+    if (Doc->simulation) {
+      SimTime = Doc->SimTime;
+      QString libs = Doc->Libraries.lower();
+      if(libs.isEmpty()) {
+	libs = "-Wl";
+      } else {
+	libs.replace(" ",",-l");
+	libs = "-Wl,-l" + libs;
+      }
+      CommandLine << pathName(QucsSettings.BinDir + QucsDigi)
+		  << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+		  << pathName(QucsSettings.BinDir) << libs;
+    }
+    // Module.
+    else {
+      QString text = Doc->text();
+      VHDL_File_Info VInfo (text);
+      QString entity = VInfo.EntityName.lower();
+      QString lib = Doc->Library.lower();
+      if (lib.isEmpty()) lib = "work";
+      QString dir = QDir::convertSeparators (QucsHomeDir.path());
+      QDir vhdlDir(dir);
+      if(!vhdlDir.exists("vhdl"))
+	if(!vhdlDir.mkdir("vhdl")) {
+	  ErrText->insert(tr("ERROR: Cannot create VHDL directory \"%1\"!")
+			  .arg(vhdlDir.path()+"/vhdl"));
+	  return;
+	}
+      vhdlDir.setPath(vhdlDir.path()+"/vhdl");
+      if(!vhdlDir.exists(lib))
+	if(!vhdlDir.mkdir(lib)) {
+	  ErrText->insert(tr("ERROR: Cannot create VHDL directory \"%1\"!")
+			  .arg(vhdlDir.path()+"/"+lib));
+	  return;
+	}
+      vhdlDir.setPath(vhdlDir.path()+"/"+lib);
+      QFile destFile;
+      destFile.setName(vhdlDir.filePath(entity+".vhdl"));
+      if(!destFile.open(IO_WriteOnly)) {
+	ErrText->insert(tr("ERROR: Cannot create \"%1\"!")
+			.arg(destFile.name()));
+	return;
+      }
+      destFile.writeBlock(text.ascii(), text.length());
+      destFile.close();
+      CommandLine << pathName(QucsSettings.BinDir + QucsDigiLib)
+		  << "netlist.txt" << pathName(SimPath) << entity << lib;
+    }
   }
+  // Simulate schematic window.
   else {
     // output NodeSets, SPICE simulations etc.
     for(QStringList::Iterator it = Collect.begin();
 	it != Collect.end(); ++it) {
       // don't put library includes into netlist...
-      if ((*it).right(4) != ".lst") {
+      if ((*it).right(4) != ".lst" &&
+	  (*it).right(5) != ".vhdl" &&
+	  (*it).right(4) != ".vhd" &&
+	  (*it).right(2) != ".v") {
 	Stream << *it << '\n';
       }
     }
@@ -357,25 +413,13 @@ void SimMessage::startSimulator()
       }
     } else {
       if (isVerilog) {
-#ifdef __MINGW32__
-	CommandLine << getShortPathName(QucsSettings.BinDir + QucsVeri)
-		    << "netlist.txt" << DataSet
-		    << SimTime << getShortPathName(SimPath)
-		    << getShortPathName(QucsSettings.BinDir) << "-c";
-#else
-	CommandLine << QucsSettings.BinDir + QucsVeri << "netlist.txt"
-           << DataSet << SimTime << SimPath << QucsSettings.BinDir << "-c";
-#endif
+	CommandLine << pathName(QucsSettings.BinDir + QucsVeri)
+		    << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+		    << pathName(QucsSettings.BinDir) << "-c";
       } else {
-#ifdef __MINGW32__
-	CommandLine << getShortPathName(QucsSettings.BinDir + QucsDigi)
-		    << "netlist.txt" << DataSet
-		    << SimTime << getShortPathName(SimPath)
-		    << getShortPathName(QucsSettings.BinDir) << "-c";
-#else
-	CommandLine << QucsSettings.BinDir + QucsDigi << "netlist.txt"
-           << DataSet << SimTime << SimPath << QucsSettings.BinDir << "-c";
-#endif
+	CommandLine << pathName(QucsSettings.BinDir + QucsDigi)
+		    << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+		    << pathName(QucsSettings.BinDir) << "-Wl" << "-c";
       }
     }
   }
