@@ -206,6 +206,18 @@ QString Arrow::save()
   return s;
 }
 
+// --------------------------------------------------------------------------
+QString Arrow::saveCpp()
+{
+  // arrow not allowed in symbols, thus we use line here
+  QString s = 
+    QString ("new Line (%1, %2, %3, %4, QPen (QColor (\"%5\"), %6, %7))").
+    arg(cx+x1).arg(cy+y1).arg(cx+x2).arg(cy+y2).
+    arg(Pen.color().name()).arg(Pen.width()).arg(toPenString(Pen.style()));
+  s = "Lines.append (" + s + ");";
+  return s;
+}
+
 // --------------------------------------------------------------------------
 // Checks if the resize area was clicked.
 bool Arrow::resizeTouched(float fX, float fY, float len)
