@@ -158,6 +158,16 @@ QString PortSymbol::save()
   return s;
 }
 
+// --------------------------------------------------------------------------
+QString PortSymbol::saveCpp()
+{
+  QString s = 
+    QString ("new Port (%1, %2)").
+    arg(cx).arg(cy);
+  s = "Ports.append (" + s + "); /* " + nameStr + " */";
+  return s;
+}
+
 // --------------------------------------------------------------------------
 // Checks if the coordinates x/y point to the painting.
 bool PortSymbol::getSelected(float fX, float fY, float)
