@@ -43,17 +43,24 @@ public:
   virtual void  showAll() {};
   virtual void  showNoZoom() {};
 
+  static QString fileSuffix (const QString&);
+  QString fileSuffix (void);
+  static QString fileBase (const QString&);
+  QString fileBase (void);
+
   QString DocName;
   QString DataSet;     // name of the default dataset
   QString DataDisplay; // name of the default data display
+  QString Script;
   QString SimTime;     // used for VHDL simulation, but stored in datadisplay
   QDateTime lastSaved;
 
   float Scale;
   QucsApp *App;
   bool DocChanged;
-  bool SimOpenDpl;  // open data display after simulation ?
-  int  showBias;    // -1=no, 0=calculation running, >0=show DC bias points
+  bool SimOpenDpl;   // open data display after simulation ?
+  bool SimRunScript; // run script after simulation ?
+  int  showBias;     // -1=no, 0=calculation running, >0=show DC bias points
   bool GridOn;
   int  tmpPosX, tmpPosY;
 };
