@@ -180,6 +180,68 @@ bool Schematic::pasteFromClipboard(QTextStream *stream, QPtrList<Element> *pe)
   return true;
 }
 
+// -------------------------------------------------------------
+int Schematic::saveSymbolCpp (void)
+{
+  QFileInfo info (DocName);
+  QString cppfile = info.dirPath () + QDir::separator() + DataSet;
+  QFile file (cppfile);
+
+  if (!file.open (IO_WriteOnly)) {
+    QMessageBox::critical (0, QObject::tr("Error"),
+		   QObject::tr("Cannot save C++ file \"%1\"!").arg(cppfile));
+    return -1;
+  }
+
+  QTextStream stream (&file);
+
+  // automatically compute boundings of drawing
+  int xmin = INT_MAX;
+  int ymin = INT_MAX;
+  int xmax = INT_MIN;
+  int ymax = INT_MIN;
+  int x1, y1, x2, y2;
+  int maxNum = 0;
+  Painting * pp;
+
+  stream << "  // symbol drawing code\n";
+  for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ()) {
+    if (pp->Name == ".ID ") continue;
+    if (pp->Name == ".PortSym ") {
+      if (((PortSymbol*)pp)->numberStr.toInt() > maxNum)
+	maxNum = ((PortSymbol*)pp)->numberStr.toInt();
+      continue;
+    }
+    pp->Bounding (x1, y1, x2, y2);
+    if (x1 < xmin) xmin = x1;
+    if (x2 > xmax) xmax = x2;
+    if (y1 < ymin) ymin = y1;
+    if (y2 > ymax) ymax = y2;
+    stream << "  " << pp->saveCpp () << "\n";
+  }
+
+  stream << "\n  // terminal definitions\n";
+  for (int i = 1; i <= maxNum; i++) {
+    for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ()) {
+      if (pp->Name == ".PortSym ")
+	if (((PortSymbol*)pp)->numberStr.toInt() == i)
+	  stream << "  " << pp->saveCpp () << "\n";
+    }
+  }
+
+  stream << "\n  // symbol boundings\n"
+	 << "  x1 = " << xmin << "; " << "  y1 = " << ymin << ";\n"
+	 << "  x2 = " << xmax << "; " << "  y2 = " << ymax << ";\n";
+
+  stream << "\n  // property text position\n";
+  for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ())
+    if (pp->Name == ".ID ")
+      stream << "  " << pp->saveCpp () << "\n";
+
+  file.close ();
+  return 0;
+}
+
 // -------------------------------------------------------------
 // Returns the number of subcircuit ports.
 int Schematic::saveDocument()
@@ -211,6 +273,8 @@ int Schematic::saveDocument()
   stream << "  <DataSet=" << DataSet << ">\n";
   stream << "  <DataDisplay=" << DataDisplay << ">\n";
   stream << "  <OpenDisplay=" << SimOpenDpl << ">\n";
+  stream << "  <Script=" << Script << ">\n";
+  stream << "  <RunScript=" << SimRunScript << ">\n";
   stream << "  <showFrame=" << showFrame << ">\n";
 
   QString t;
@@ -255,6 +319,15 @@ int Schematic::saveDocument()
   stream << "</Paintings>\n";
 
   file.close();
+
+  // additionally save symbol C++ code if in a symbol drawing and the
+  // associated file is a Verilog-A file
+  if (fileSuffix () == "sym") {
+    if (fileSuffix (DataDisplay) == "va") {
+      saveSymbolCpp ();
+    }
+  }
+
   return 0;
 }
 
@@ -301,6 +374,10 @@ bool Schematic::loadProperties(QTextStream *stream)
     else if(cstr == "OpenDisplay")
 		if(nstr.toInt(&ok) == 0) SimOpenDpl = false;
 		else SimOpenDpl = true;
+    else if(cstr == "Script") Script = nstr;
+    else if(cstr == "RunScript")
+		if(nstr.toInt(&ok) == 0) SimRunScript = false;
+		else SimRunScript = true;
     else if(cstr == "showFrame")
 		showFrame = nstr.at(0).latin1() - '0';
     else if(cstr == "FrameText0") convert2Unicode(Frame_Text0 = nstr);
@@ -338,11 +415,11 @@ void Schematic::simpleInsertComponent(Component *c)
     // check if new node lies upon existing node
     for(pn = DocNodes.first(); pn != 0; pn = DocNodes.next())
       if(pn->cx == x) if(pn->cy == y) {
-	if (!pn->Type.isEmpty()) {
-	  pp->Type = pn->Type;
+	if (!pn->DType.isEmpty()) {
+	  pp->Type = pn->DType;
 	}
 	if (!pp->Type.isEmpty()) {
-	  pn->Type = pp->Type;
+	  pn->DType = pp->Type;
 	}
 	break;
       }
@@ -353,7 +430,7 @@ void Schematic::simpleInsertComponent(Component *c)
     }
     pn->Connections.append(c);  // connect schematic node to component node
     if (!pp->Type.isEmpty()) {
-      pn->Type = pp->Type;
+      pn->DType = pp->Type;
     }
 
     pp->Connection = pn;  // connect component node to schematic node
@@ -787,9 +864,9 @@ void Schematic::collectDigitalSignals(void)
   for(pn = DocNodes.first(); pn != 0; pn = DocNodes.next()) {
     DigMap::Iterator it = Signals.find(pn->Name);
     if(it == Signals.end()) { // avoid redeclaration of signal
-      Signals.insert(pn->Name, DigSignal(pn->Name, pn->Type));
-    } else if (!pn->Type.isEmpty()) {
-      it.data().Type = pn->Type;
+      Signals.insert(pn->Name, DigSignal(pn->Name, pn->DType));
+    } else if (!pn->DType.isEmpty()) {
+      it.data().Type = pn->DType;
     }
   }
 }
@@ -882,7 +959,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
 	  // apply in/out signal types of subcircuit
 	  for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
 	    pp->Type = it.data().PortTypes[i];
-	    pp->Connection->Type = pp->Type;
+	    pp->Connection->DType = pp->Type;
 	  }
 	}
         continue;   // insert each subcircuit just one time
@@ -908,7 +985,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
 	// save in/out signal types of subcircuit
 	for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
 	  pp->Type = d->PortTypes[i];
-	  pp->Connection->Type = pp->Type;
+	  pp->Connection->DType = pp->Type;
 	}
 	sub.PortTypes = d->PortTypes;
 	FileList.replace(f, sub);
@@ -1142,7 +1219,7 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
       DigMap::Iterator it = Signals.find(*it_name);
       (*it_type) = it.data().Type;
       // propagate type to port symbol
-      pc->Ports.getFirst()->Connection->Type = *it_type;
+      pc->Ports.getFirst()->Connection->DType = *it_type;
 
       if(!isAnalog) {
 	if (isVerilog) {
@@ -1224,12 +1301,16 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
       // ..... digital subcircuit ...................................
       (*tstream) << "\nmodule Sub_" << Type << " ("
 		 << SubcircuitPortNames.join(", ") << ");\n";
+
+      // subcircuit in/out connections
       if(!InPorts.isEmpty())
 	(*tstream) << "  input " << InPorts.join(", ") << ";\n";
       if(!OutPorts.isEmpty())
 	(*tstream) << "  output " << OutPorts.join(", ") << ";\n";
       if(!InOutPorts.isEmpty())
 	(*tstream) << "  inout " << InOutPorts.join(", ") << ";\n";
+
+      // subcircuit connections
       if(!Signals.isEmpty()) {
 	QValueList<DigSignal> values = Signals.values();
 	QValueList<DigSignal>::iterator it;
@@ -1239,6 +1320,7 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
       }
       (*tstream) << "\n";
 
+      // subcircuit parameters
       for(pi = SymbolPaints.first(); pi != 0; pi = SymbolPaints.next())
 	if(pi->Name == ".ID ") {
 	  SubParameter *pp;
@@ -1255,16 +1337,25 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
 	  break;
 	}
 
+      // write all equations into netlist file
+      for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
+	if(pc->Model == "Eqn") {
+	  (*tstream) << pc->get_Verilog_Code(NumPorts);
+	}
+      }
+
       if(Signals.find("gnd") != Signals.end())
 	(*tstream) << "  assign gnd = 0;\n";  // should appear only once
 
       // write all components into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	s = pc->get_Verilog_Code(NumPorts);
-	if(s.at(0) == '') {
-	  ErrText->insert(s.mid(1));
+	if(pc->Model != "Eqn") {
+	  s = pc->get_Verilog_Code(NumPorts);
+	  if(s.at(0) == '') {
+	    ErrText->insert(s.mid(1));
+	  }
+	  else (*tstream) << s;
 	}
-	else (*tstream) << s;
       }
 
       (*tstream) << "endmodule\n";
@@ -1308,6 +1399,16 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
 	}
       }
 
+      // write all equations into netlist file
+      for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
+	if(pc->Model == "Eqn") {
+	  ErrText->insert(
+            QObject::tr("WARNING: Equations in \"%1\" are 'time' typed.").
+	    arg(pc->Name));
+	  (*tstream) << pc->get_VHDL_Code(NumPorts);
+	}
+      }
+
       (*tstream) << "begin\n";
 
       if(Signals.find("gnd") != Signals.end())
@@ -1315,11 +1416,13 @@ void Schematic::createSubNetlistPlain(QTextStream *stream, QTextEdit *ErrText,
 
       // write all components into netlist file
       for(pc = DocComps.first(); pc != 0; pc = DocComps.next()) {
-	s = pc->get_VHDL_Code(NumPorts);
-	if(s.at(0) == '') {
-	  ErrText->insert(s.mid(1));
+	if(pc->Model != "Eqn") {
+	  s = pc->get_VHDL_Code(NumPorts);
+	  if(s.at(0) == '') {
+	    ErrText->insert(s.mid(1));
+	  }
+	  else (*tstream) << s;
 	}
-	else (*tstream) << s;
       }
 
       (*tstream) << "end architecture;\n";
